@@ -19,9 +19,23 @@ sub protect(&) {
 
     my ($ok, $error);
     {
-        local ($@, $!);
+        my ($msg, $no, $dolocal);
+        if ($^O eq 'MSWin32' && $] < 5.020002) {
+            $dolocal = 0;
+            $msg = $@;
+            $no  = $!;
+        }
+        else {
+            $dolocal = 1;
+        }
+        local ($@, $!) if $dolocal;
         $ok = eval { $code->(); 1 } || 0;
         $error = $@ || "Error was squashed!\n";
+
+        unless ($dolocal) {
+            $@ = $msg;
+            $! = $no;
+        }
     }
     die $error unless $ok;
     return $ok;
@@ -33,11 +47,26 @@ sub try(&) {
     my $ok;
 
     {
-        local ($@, $!, $SIG{__DIE__});
+        my ($msg, $no, $dolocal, $die);
+        if ($^O eq 'MSWin32' && $] < 5.020002) {
+            $dolocal = 0;
+            $msg = $@;
+            $no  = $!;
+            $die = delete $SIG{__DIE__};
+        }
+        else {
+            $dolocal = 1;
+        }
+        local ($@, $!, $SIG{__DIE__}) if $dolocal;
         $ok = eval { $code->(); 1 } || 0;
         unless($ok) {
             $error = $@ || "Error was squashed!\n";
         }
+        unless ($dolocal) {
+            $@ = $msg;
+            $! = $no;
+            $SIG{__DIE__} = $die;
+        }
     }
 
     return wantarray ? ($ok, $error) : $ok;
@@ -55,8 +84,7 @@ sub spoof {
     my $error;
     my $ok;
 
-    {
-        local ($@, $!);
+    protect {
         $ok = eval <<"        EOT" || 0;
 package $call->[0];
 #line $call->[2] "$call->[1]"
@@ -66,7 +94,7 @@ $code;
         unless($ok) {
             $error = $@ || "Error was squashed!\n";
         }
-    }
+    };
 
     return wantarray ? ($ok, $error) : $ok;
 }
@@ -171,15 +199,11 @@ __END__
 
 =head1 NAME
 
-Test::Stream::Util
+Test::Stream::Util - Tools used by Test::Stream and friends.
 
 =head1 DESCRIPTION
 
-Tools for generating accessors and other object bits and pieces.
-
-=head1 SYNOPSYS
-
-    ...
+Collection of tools used by L<Test::Stream> and friends.
 
 =head1 EXPORTS
 
@@ -200,6 +224,38 @@ protect $@ and $! from changes. $@ and $! will be restored to whatever they
 were before the run so long as it is successful. If the run fails $! will still
 be restored, but $@ will contain the exception being thrown.
 
+=item spoof([$package, $file, $line], "Code String", @args)
+
+Eval the string provided as the second argument pretending to be the specified
+package, file, and line number. The main purpose of this is to have warnings
+and exceptions be thrown from the desired context.
+
+Additional arguments will be added to an C<@args> variable that is available to
+you inside your code string.
+
+=item $usable_pattern = is_regex($PATTERN)
+
+Check of the specified argument is a regex. This is mainly important in older
+perls where C<qr//> did not work the way it does now.
+
+=item is_dualvar
+
+Do not use this, use Scalar::Util::isdual instead. This is kept around for
+legacy support.
+
+=item unoverload
+
+=item unoverload_str
+
+=item unoverload_num
+
+Legacy tools for unoverloading things.
+
+=item $proper = translate_filename($encoding, $raw)
+
+Translate filenames from whatever perl has them stored as into the proper,
+specified, encoding.
+
 =back
 
 =encoding utf8
